@@ -1,12 +1,12 @@
-update.jags <- function(object, niter = 1, by, ...)
+update.jags <- function(object, n.iter = 1, by, ...)
 {
-    if (!is.numeric(niter) || niter < 1) {
-        stop("Invalid niter")
+    if (!is.numeric(n.iter) || n.iter < 1) {
+        stop("Invalid n.iter")
     }
     if (missing(by))
-	by <- floor(niter/50)
+	by <- floor(n.iter/50)
 
-    object$update(niter, by)
+    object$update(n.iter, by)
     invisible(NULL)
 }
     
